DrDownload class
Constructors
- DrDownload({required String url, required double percent, required int downloadedBytes})
-
const
Properties
- downloadedBytes → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- percent → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMap(
dynamic message) → DrDownload